==> fd-help-800.2017.12.14-noarch-1.tar.gz: fd-help/usr/share/doc/fd-help/links.md <==
%%textdomain fatdoghelp
![ ](fatdog64.png)
# Resources and additional information

## Links

[Firmware](http://git.kernel.org/cgit/linux/kernel/git/dwmw2/linux-firmware.git) --- If your looking for firmware that's not in Fatdog64, you'll want to try here and the manufacturer's web site.

[Barry's Blog](http://bkhome.org/blog/) --- Barry Kauler, the creator of Puppy Linux, has a blog here.

[Puppylinux.com](http://www.puppylinux.com/) --- Barry's web site.

[jamesbond3142's blog](http://lightofdawn.org/blog/) --- Blog from one of Fatdog64 maintainer.

[Linux From Scratch (LFS)](http://linuxfromscratch.org/) --- Fatdog64 is build following LFS principles and build recipes.

[cateee.net](http://cateee.net/lkddb/web-lkddb/) --- If your compiling a kernel and need to know what a config option means look here.

[Phoronix](http://www.phoronix.com/scan.php?page=home) --- Linux and hardware news.

## Games

[Urban Terror](http://www.urbanterror.info/news/)  --- This is a first person shooter (FPS). Best free one I've seen.

[Open Arena](http://www.openarena.ws/smfnews.php)  --- A FPS game, similar to Quake 3, this one is actually GPLed.

[Smokin Guns](http://www.smokin-guns.org/)Smokin Guns] --- A FPS game set in the wild west of the 1800s.

[Linux Game Database](http://www.lgdb.org/games)  --- I haven't actually used this much, but it looks good.

The games listed above require no installation, just unzip and play. They are quite large, in the 500MB to 700MB range. They all use the GPLed Quake 3 engine so they can run on modest hardware.

ATI and Intel hardware acceleration is supported by Fatdog64 with the included open source drivers, but you'll get better performance from the propritary ATI driver if it supports your card. Make sure you check to see if the version in the pet repository supports your card before installing. For Nvidia you'll need the Nvidia pet package installed.

There are a few games in the pet repository too.

==> fd-help-811.2020.08.26-noarch-1.tar.gz: fd-help/usr/share/doc/fd-help/links.md <==
%%textdomain fatdoghelp
![ ](fatdog64.png)
# Resources and additional information

## Links

[Firmware](http://git.kernel.org/cgit/linux/kernel/git/dwmw2/linux-firmware.git) --- If your looking for firmware that's not in Fatdog64, you'll want to try here and the manufacturer's web site.

[Barry's Blog](http://bkhome.org/blog/) --- Barry Kauler, the creator of Puppy Linux, has a blog here.

[Puppylinux.com](http://www.puppylinux.com/) --- Barry's web site.

[jamesbond3142's blog](http://lightofdawn.org/blog/) --- Blog from one of Fatdog64 maintainer.

[Linux From Scratch (LFS)](http://linuxfromscratch.org/) --- Fatdog64 is built following LFS principles and build recipes.

[cateee.net](http://cateee.net/lkddb/web-lkddb/) --- If your compiling a kernel and need to know what a config option means look here.

[Phoronix](http://www.phoronix.com/scan.php?page=home) --- Linux and hardware news.

## Games

[Urban Terror](http://www.urbanterror.info/news/)  --- This is a first person shooter (FPS). Best free one I've seen.

[Open Arena](http://www.openarena.ws/smfnews.php)  --- A FPS game, similar to Quake 3, this one is actually GPLed.

[Smokin Guns](http://www.smokin-guns.org/)Smokin Guns] --- A FPS game set in the wild west of the 1800s.

[Linux Game Database](http://www.lgdb.org/games)  --- I haven't actually used this much, but it looks good.

The games listed above require no installation, just unzip and play. They are quite large, in the 500MB to 700MB range. They all use the GPLed Quake 3 engine so they can run on modest hardware.

ATI and Intel hardware acceleration is supported by Fatdog64 with the included open source drivers, but you'll get better performance from the propritary ATI driver if it supports your card. Make sure you check to see if the version in the pet repository supports your card before installing. For Nvidia you'll need the Nvidia pet package installed.

There are a few games in the pet repository too.
